##  Configuring SSO
With the self-service configuration you independently setup your SSO authentication for SAP LeanIX. To learn more, see [SSO Configuration Process](https://help.sap.com/docs/leanix/ea/sso-configuration-process?locale=en-US&state=PRODUCTION&version=CLOUD).
